==> MetaMax-1.9.7.tar.gz: MetaMax/function.admin_analyticstab.php <==
<?php
if( !isset($gCms) ) exit;

// CreateFormStart sets up a proper form tag that will cause the submit to
// return control to this module for processing.

$analytics = array();
$analytics[$this->Lang('analytics_select')] = '-1';
$analytics[$this->Lang('analytics_single')] = '0';
$analytics[$this->Lang('analytics_sub')] = '1';
$analytics[$this->Lang('analytics_multiple')] = '2';

$smarty->assign('startform', $this->CreateFormStart ($id, 'updateanalytics', $returnid));
$smarty->assign('endform', $this->CreateFormEnd ());
$smarty->assign('submit', $this->CreateInputSubmit ($id, 'analyticssubmitbutton', $this->Lang('submit')));
$smarty->assign('legend_analytics_title',$this->Lang('analytics_title_legend'));
$smarty->assign('legend_search_title',$this->Lang('search_title_legend'));
$smarty->assign('query_help',$this->Lang('query_help'));
$smarty->assign('results_help',$this->Lang('results_help'));
$smarty->assign('legend_bing_title',$this->Lang('bing_title_legend'));

$smarty->assign('title_analyticstype_title',$this->Lang('analytics_type'));
$smarty->assign('input_analyticstype_title',$this->CreateInputDropdown($id,'analyticstype_title',$analytics,$this->GetPreference('analyticstype_title','-1'),$this->GetPreference('analyticstype_title','-1')));

$smarty->assign('title_analytics_support',$this->Lang('analytics_support'));
$smarty->assign('input_analytics_support', $this->CreateInputCheckbox($id,'analytics_support','1', $this->GetPreference('analytics_support','0')));

$smarty->assign('title_propertyid_title',$this->Lang('propertyid_title'));
$smarty->assign('input_propertyid_title',$this->CreateInputText($id,'propertyid_title',$this->GetPreference('propertyid_title',''),50,255));

$smarty->assign('title_webmasterid_title',$this->Lang('webmasterid_title'));
$smarty->assign('input_webmasterid_title',$this->CreateInputText($id,'webmasterid_title',$this->GetPreference('webmasterid_title',''),50,255));

$smarty->assign('title_pretty_title',$this->Lang('pretty_title'));
$smarty->assign('input_pretty_title', $this->CreateInputCheckbox($id,'pretty_title','1', $this->GetPreference('pretty_title','0')));

$smarty->assign('title_post_title',$this->Lang('post_title'));
$smarty->assign('input_post_title', $this->CreateInputCheckbox($id,'post_title','1', $this->GetPreference('post_title','0')));

$smarty->assign('title_query_title',$this->Lang('query_title'));
$smarty->assign('input_query_title',$this->CreateInputText($id,'query_title',$this->GetPreference('query_title',''),50,255));

$smarty->assign('title_results_title',$this->Lang('results_title'));
$smarty->assign('input_results_title',$this->CreateInputText($id,'results_title',$this->GetPreference('results_title',''),50,255));

$smarty->assign('title_bingid_title',$this->Lang('bingid_title'));
$smarty->assign('input_bingid_title',$this->CreateInputText($id,'bingid_title',$this->GetPreference('bingid_title',''),50,255));

// Display the populated template

echo $this->ProcessTemplate ('adminanalytics.tpl');

?>

==> MetaMax-1.9.9.3.tar.gz: MetaMax/function.admin_analyticstab.php <==
<?php
if( !isset($gCms) ) exit;

// CreateFormStart sets up a proper form tag that will cause the submit to
// return control to this module for processing.

$analytics = array();
$analytics[$this->Lang('analytics_select')] = '-1';
$analytics[$this->Lang('analytics_single')] = '0';
$analytics[$this->Lang('analytics_sub')] = '1';
$analytics[$this->Lang('analytics_multiple')] = '2';
$analytics[$this->Lang('analytics_universal')] = '3';

$smarty->assign('startform', $this->CreateFormStart ($id, 'updateanalytics', $returnid));
$smarty->assign('endform', $this->CreateFormEnd ());
$smarty->assign('submit', $this->CreateInputSubmit ($id, 'analyticssubmitbutton', $this->Lang('submit')));
$smarty->assign('legend_analytics_title',$this->Lang('analytics_title_legend'));
$smarty->assign('legend_search_title',$this->Lang('search_title_legend'));
$smarty->assign('query_help',$this->Lang('query_help'));
$smarty->assign('results_help',$this->Lang('results_help'));
$smarty->assign('analytics_help',$this->Lang('analytics_help'));
$smarty->assign('legend_bing_title',$this->Lang('bing_title_legend'));

$smarty->assign('title_analyticstype_title',$this->Lang('analytics_type'));
$smarty->assign('input_analyticstype_title',$this->CreateInputDropdown($id,'analyticstype_title',$analytics,$this->GetPreference('analyticstype_title','-1'),$this->GetPreference('analyticstype_title','-1')));

$smarty->assign('title_analytics_support',$this->Lang('analytics_support'));
$smarty->assign('input_analytics_support', $this->CreateInputCheckbox($id,'analytics_support','1', $this->GetPreference('analytics_support','0')));

$smarty->assign('title_propertyid_title',$this->Lang('propertyid_title'));
$smarty->assign('input_propertyid_title',$this->CreateInputText($id,'propertyid_title',$this->GetPreference('propertyid_title',''),50,255));

$smarty->assign('title_webmasterid_title',$this->Lang('webmasterid_title'));
$smarty->assign('input_webmasterid_title',$this->CreateInputText($id,'webmasterid_title',$this->GetPreference('webmasterid_title',''),50,255));

$smarty->assign('title_pretty_title',$this->Lang('pretty_title'));
$smarty->assign('input_pretty_title', $this->CreateInputCheckbox($id,'pretty_title','1', $this->GetPreference('pretty_title','0')));

$smarty->assign('title_post_title',$this->Lang('post_title'));
$smarty->assign('input_post_title', $this->CreateInputCheckbox($id,'post_title','1', $this->GetPreference('post_title','0')));

$smarty->assign('title_query_title',$this->Lang('query_title'));
$smarty->assign('input_query_title',$this->CreateInputText($id,'query_title',$this->GetPreference('query_title',''),50,255));

$smarty->assign('title_results_title',$this->Lang('results_title'));
$smarty->assign('input_results_title',$this->CreateInputText($id,'results_title',$this->GetPreference('results_title',''),50,255));

$smarty->assign('title_bingid_title',$this->Lang('bingid_title'));
$smarty->assign('input_bingid_title',$this->CreateInputText($id,'bingid_title',$this->GetPreference('bingid_title',''),50,255));

// Display the populated template

echo $this->ProcessTemplate ('adminanalytics.tpl');

?>
